var _mbTree = null;			// the tree representation
var _mbList = null;			// the list representation

//
// a \"simple\" tree class w/ back edges
//
function mbTreeNode (icon, title, link, target, descript, vis)
{
	this.parentNode = null;
	this.firstChild = null;
	this.lastChild = null;
	this.prevSibling = null;
	this.nextSibling = null;

	this.icon = icon;
	this.title = title;
	this.link = link;
	this.target = target;
	this.descript = descript;
	this.vis = vis;

	//
	// attach a node at the end of the child tree
	//
	// if childNode is null or undefined, nothing is done.
	//
	this.addChild = function (childNode)
	{
		if (!childNode)
			return;
		if (this.lastChild == null)
		{
			this.firstChild = childNode;
			this.lastChild = childNode;
			childNode.parentNode = this;
		}
		else
		{
			this.lastChild.nextSibling = childNode;
			childNode.prevSibling = this.lastChild;
			this.lastChild = childNode;
			childNode.parentNode = this;
		}
	};

	//
	// assumed that this. prevSibling, nextSibling are null
	//
	this.insertBefore = function (node)
	{
		this.parentNode = node.parentNode;
		if (node.prevSibling)
		{
			node.prevSibling.nextSibling = this;
			this.prevSibling = node.prevSibling;
		}
		else
		{
			if (node.parentNode &&
				node.parentNode.firstChild == node)
				node.parentNode.firstChild = this;
		}
		this.nextSibling = node;
		node.prevSibling = this;
	};

	//
	// assumed that this. prevSibling, nextSibling are null
	//
	this.insertAfter = function (node)
	{
		this.parentNode = node.parentNode;
		if (node.nextSibling)
		{
			node.nextSibling.prevSibling = this;
			this.nextSibling = node.nextSibling;
		}
		else
		{
			if (node.parentNode &&
				node.parentNode.lastChild == this)
				node.parentNode.lastChild = this;
		}
		this.prevSibling = node;
		node.nextSibling = this;
	};

	//
	// remove a this node from other tree structures
	//
	this.remove = function ()
	{
		if (this.parentNode)
		{
			var parentNode = this.parentNode;
			if (parentNode.firstChild == this)
				parentNode.firstChild = this.nextSibling;
			if (parentNode.lastChild == this)
				parentNode.lastChild = this.prevSibling;
		}

		if (this.prevSibling)
			this.prevSibling.nextSibling = this.nextSibling;
		if (this.nextSibling)
			this.nextSibling.prevSibling = this.prevSibling;

		this.parentNode = null;
		this.prevSibling = null;
		this.nextSibling = null;
	};

	//
	// generate a preorder list of nodes
	//
	this.generateList = function (list)
	{
		list.push (this);
		var child;
		for (child = this.firstChild; child != null; child = child.nextSibling)
			child.generateList (list);
	};

	//
	// generate a preorder list of <option> for <select>
	//
	this.generateOption = function (indent)
	{
		var str = '<option>' + indent;
		if (this.icon == _cmSplit)
			return str + '--------------</option>\n';
		str += this.title + '</option>\n';
		var child;
		for (child = this.firstChild; child != null; child = child.nextSibling)
			str += child.generateOption (indent + '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;');
		return str;
	};

	//
	// generate the correspond tree/menu code for JSCookMenu/JSCookTree
	//
	this.generateCode = function (indent)
	{
		var str = indent;

		if (this.icon == _cmSplit)
		{
			if (this.nextSibling)
				return str + '_cmSplit,\n';
			else
				return str + '_cmSplit\n';
		}

		str += '[';
		str += (this.icon == null) ? 'null,' : '\'' + this.icon + '\',';
		str += (this.title == null) ? 'null,' : '\'' + this.title + '\',';
		str += (this.link == null) ? 'null,' : '\'' + this.link + '\',';
		str += (this.target == null) ? 'null,' : '\'' + this.target + '\',';
		str += (this.descript == null) ? 'null,' : '\'' + this.descript + '\',';
		str += (this.vis == null) ? 'null' : '\'' + this.vis + '\'';

		if (this.firstChild)
			str += ',\n';
		var child;
		for (child = this.firstChild; child != null; child = child.nextSibling)
			str += child.generateCode (indent + '\t');
		if (this.firstChild)
			str += indent;

		if (this.nextSibling)
			str += '],\n';
		else
			str += ']\n';
		return str;
	};
}

//
// import tree
//
function mbImport ()
{
	try
	{
		var obj = cmGetObject ('importArea');
		var tmpTree = null;
		eval ('tmpTree = ' + obj.value);
		tmpTree = mbConvertTree (tmpTree);

		_mbTree = tmpTree;
		mbShowTree ();
	}
	catch (ex)
	{
		//alert ('Import Error - ' + cmGetProperties (ex));
		alert ('You are receiving this error due to the following possible reasons.\n1. A call to configure.php was not found in your subheader.php\n2. A call to index.php was not found in your used themes\n3. DHTML MENU was not infused properly from the Admin Panel\n4. Folder/Files permissions are not set properly\n5. siteurl settings was not configured properly.\n6. You might have entered some errors in the menuitems.js \n\nPlease read through the installation text file or download the manual to aid you in fixing the problem.');
		return;
	}
}

//
// convert JSCookMenu/JSCookTree representation to internal representation
//
function mbConvertTree (tree)
{
	var i;
	var firstNode = null;
	var lastNode = null;
	var thisNode = null;
	for (i = 0; i < tree.length; ++i)
	{
		thisNode = mbConvertTreeSub (tree[i]);
		if (firstNode == null)
			firstNode = thisNode;
		if (lastNode)
			thisNode.insertAfter (lastNode);
		lastNode = thisNode;
	}
	return firstNode;
}

function mbConvertTreeSub (tree)
{
	if (tree == _cmSplit)
		return new mbTreeNode (_cmSplit, null, null, null, null, null);
	if (!tree)
		return null;
	var tmpTree = new mbTreeNode (tree[0], tree[1], tree[2], tree[3], tree[4], tree[5]);
	var i;
	for (i = 6; i < tree.length; ++i)
		tmpTree.addChild (mbConvertTreeSub (tree[i]));
	return tmpTree;
}

//
// shows the current structure from scratch
//
function mbShowTree ()
{
	_mbList = new Array ();	// clear the old tree list representation
	var str = '';

	if (_mbTree)
	{
		var tmpTree;
		for (tmpTree = _mbTree; tmpTree; tmpTree = tmpTree.nextSibling)
		{
			tmpTree.generateList (_mbList);
			str += tmpTree.generateOption ('');
		}
	}
	str = '<select class=\"textbox\" id=\"treeArea\" onchange=\"mbSelectOnChange ()\" size=\"20\" style=\"font-family: arial; font-size: 10pt; width: 99%\">' + str +
		  '</select>';
	cmGetObject ('treeTD').innerHTML = str;
}

//
// clear the tree
//
function mbClearTree ()
{
	_mbTree = null;
	mbShowTree ();
}

//
// show the code for the current tree
//
function mbShowCode ()
{
	var str = '';
	if (_mbTree)
	{
		var tmpTree;
		for (tmpTree = _mbTree; tmpTree; tmpTree = tmpTree.nextSibling)
			str += tmpTree.generateCode ('\t');
	}
	str = '[\n' + str + '];\n';
	cmGetObject ('codeArea').value = str;
}

//
// return the selected node in 'treeArea'
//
function mbGetSelectedIndex ()
{
	var obj = cmGetObject ('treeArea');
	if (obj.selectedIndex < 0 || obj.selectedIndex >= obj.length)
		return -1;
	return obj.selectedIndex;
}

//
// set the selected node in 'treeArea'
//
function mbSetSelectedIndex (index)
{
	var obj = cmGetObject ('treeArea');
	if (index < 0 || index >= obj.length)
		return false;
	obj.selectedIndex = index;
	return true;
}

//
// get the # of child nodes plus itself
//
function mbGetNodeLength (node)
{
	if (node == undefined)
		return 0;
	if (node == _cmSplit)
		return 1;
	var len = 1;
	if (node.length > 6)
	{
		var i;
		for (i = 6; i < node.length; ++i)
			len += mbGetNodeLength (node[i]);
	}
	return len;
}

//
// add a node
//
function mbAddNode ()
{
	var title = cmGetObject ('title').value;
	if (!title)
		return;

	var icon = cmGetObject ('icon').value;
	var link = cmGetObject ('link').value;
	var target = cmGetObject ('target').value;
	var descript = cmGetObject ('descript').value;
	var vis = cmGetObject ('vis').value;

	if (!icon) icon = null;
	if (!link) link = null;
	if (!link || !target) target = null;
	if (!descript) descript = null;
	if (!vis) vis = null;

	var tmpNode = new mbTreeNode (icon, title, link, target, descript, vis);

	var index = mbGetSelectedIndex ();
	if (!_mbTree)
	{
		_mbTree = tmpNode;
	}
	else if (index < 0)
	{
		tmpNode.insertAfter (_mbList[_mbList.length - 1]);
	}
	else
	{
		tmpNode.insertAfter (_mbList[index]);
	}
	mbShowTree ();
	mbSetSelectedIndex (index + 1);
}

//
// add a child node
//
function mbAddChild ()
{
	var title = cmGetObject ('title').value;
	if (!title)
		return;

	var icon = cmGetObject ('icon').value;
	var link = cmGetObject ('link').value;
	var target = cmGetObject ('target').value;
	var descript = cmGetObject ('descript').value;
	var vis = cmGetObject ('vis').value;

	if (!icon) icon = null;
	if (!link) link = null;
	if (!link || !target) target = null;
	if (!descript) descript = null;
	if (!vis) vis = null;

	var tmpNode = new mbTreeNode (icon, title, link, target, descript, vis);

	var index = mbGetSelectedIndex ();
	if (!_mbTree)
	{
		_mbTree = tmpNode;
	}
	else if (index < 0)
	{
		tmpNode.insertAfter (_mbList[_mbList.length - 1]);
	}
	else
	{
		_mbList[index].addChild (tmpNode);
	}
	mbShowTree ();
	mbSetSelectedIndex (index);
}

//
// add a menu split
//
function mbAddSplit ()
{
	var tmpNode = new mbTreeNode (_cmSplit, null, null, null, null,null);

	var index = mbGetSelectedIndex ();
	if (!_mbTree)
	{
		_mbTree = tmpNode;
	}
	else if (index < 0)
	{
		tmpNode.insertAfter (_mbList[_mbList.length - 1]);
	}
	else
	{
		tmpNode.insertAfter (_mbList[index]);
	}
	mbShowTree ();
	mbSetSelectedIndex (mbGetNodeIndex (tmpNode));
}

//
// change the current node
//
function mbModify ()
{
	var index = mbGetSelectedIndex ();
	if (!_mbTree || index < 0)
		return;

	var title = cmGetObject ('title').value;
	if (!title)
		return;

	var icon = cmGetObject ('icon').value;
	var link = cmGetObject ('link').value;
	var target = cmGetObject ('target').value;
	var descript = cmGetObject ('descript').value;
	var vis = cmGetObject ('vis').value;

	if (!icon) icon = null;
	if (!link) link = null;
	if (!link || !target) target = null;
	if (!descript) descript = null;
	if (!vis) vis = null;

	var node = _mbList[index];

	node.icon = icon;
	node.title = title;
	node.link = link;
	node.target = target;
	node.descript = descript;
	node.vis = vis;

	mbShowTree ();
	mbSetSelectedIndex (index);
}

//
// move the current node up
//
function mbMoveUp ()
{
	var index = mbGetSelectedIndex ();
	if (!_mbTree || index < 0)
		return;

	var node = _mbList[index];

	if (!node.prevSibling)
		return;
	var prevSibling = node.prevSibling;
	node.remove ();
	node.insertBefore (prevSibling);

	if (_mbTree == prevSibling)
		_mbTree = node;

	mbShowTree ();
	mbSetSelectedIndex (mbGetNodeIndex (node));
}

//
// move the current node down
//
function mbMoveDown ()
{
	var index = mbGetSelectedIndex ();
	if (!_mbTree || index < 0)
		return;

	var node = _mbList[index];

	if (!node.nextSibling)
		return;
	var nextSibling = node.nextSibling;
	node.remove ();
	node.insertAfter (nextSibling);

	if (_mbTree == node)
		_mbTree = nextSibling;

	mbShowTree ();
	mbSetSelectedIndex (mbGetNodeIndex (node));
}

//
// indent the current node
//
function mbIndent ()
{
	var index = mbGetSelectedIndex ();
	if (index < 0)
		return;

	var node = _mbList[index];

	if (!node.prevSibling || node.prevSibling.icon == _cmSplit)
		return;

	var prevSibling = node.prevSibling;

	node.remove ();
	prevSibling.addChild (node);

	mbShowTree ();
	mbSetSelectedIndex (mbGetNodeIndex (node));
}

//
// unindent the current node
//
function mbUnindent ()
{
	var index = mbGetSelectedIndex ();
	if (index < 0)
		return;

	var node = _mbList[index];

	if (!node.parentNode)
		return;

	var parentNode = node.parentNode;

	node.remove ();

	node.insertAfter (parentNode);

	mbShowTree ();
	mbSetSelectedIndex (mbGetNodeIndex (node));
}

//
// delete the current node
//
function mbDelete ()
{
	var index = mbGetSelectedIndex ();
	if (index < 0)
		return;

	var node = _mbList[index];

	if (_mbTree == node)
		_mbTree = node.nextSibling;

	node.remove ();
	mbShowTree ();
	if (!mbSetSelectedIndex (index))
		mbSetSelectedIndex (index - 1);

	var index = mbGetSelectedIndex ();
	if (index < 0)
		return;

	var node = _mbList[index];
	var visItem = cmGetObject ('vis').length;

	cmGetObject ('icon').value = node.icon ? node.icon : '';
	cmGetObject ('title').value = node.title ? node.title : '';
	cmGetObject ('link').value = node.link ? node.link : '';
	cmGetObject ('target').value = node.target ? node.target : '';
	cmGetObject ('descript').value = node.descript ? node.descript : '';
		for(i=0;i<visItem;i++)
		{
			if(node.vis == cmGetObject ('vis').options[i].value){
				cmGetObject ('vis').selectedIndex = i;
			}
		}
}

//
// find the index of a node in _mbList
//
function mbGetNodeIndex (node)
{
	var i;
	for (i = 0; i < _mbList.length; ++i)
		if (_mbList[i] == node)
			return i;
	return -1;
}

//
// show the description of the current item being hovered
//
function mbOptionHover (obj)
{
	var descript;
	var node = _mbList[obj.index];
	if (node.icon == _cmSplit)
		descript = 'menu split';
	else
		descript = node.icon + ',' + node.title + ',' + node.link + ',' + node.target + ',' + node.descript + ',' + node.vis;
	window.defaultStatus = descript;
}

//
// clear the status
//
function mbClearStatus ()
{
	window.defaultStatus = '';
}

//
// when user selected something in <select>
function mbSelectOnChange ()
{
	var index = mbGetSelectedIndex ();
	var node = _mbList[index];
	var visItem = cmGetObject ('vis').length;
	var visC;
	var j;

	if (node.icon == _cmSplit)
		return;
	cmGetObject ('icon').value = node.icon ? node.icon : '';
	cmGetObject ('title').value = node.title ? node.title : '';
	cmGetObject ('link').value = node.link ? node.link : '';
	cmGetObject ('target').value = node.target ? node.target : '';
	cmGetObject ('descript').value = node.descript ? node.descript : '';
	cmGetObject ('vis').value = node.vis ? node.vis : '';

	temp = document.codeAreaForm.elements.length ;
	for (j=0; j < temp; j++) {
		document.codeAreaForm.elements[j].checked = 0;
	}

	visibArr = node.vis.split(".");
	for (visC=0; visC < visibArr.length; visC++ )
	{
		if (document.getElementById("CID" + visibArr[visC]))
		{
			document.getElementById("CID" + visibArr[visC]).checked = true;
		}
	}

		//for(i=0;i<visItem;i++)
		//{
		//	if(node.vis == cmGetObject ('vis').options[i].value){
		//		cmGetObject ('vis').selectedIndex = i;
		//	}
		//}
}


//save the current menu for preview
function mbPreview ()
{
	mbShowCode();
	document.getElementById ('codeAreaForm').submit();
}


//
function mbSave ()
{
	mbShowCode();
	document.getElementById ('codeAreaForm').submit();
}


function mbSaveConfig ()
{
	ConfigurationForm.submit();
}


//by: HACKERSOFT
function is_array( mixed_var ) {
	return ( mixed_var instanceof Array );
}

function str_replace(search, replace, subject) {
	var f = search, r = replace, s = subject;
	var ra = is_array(r), sa = is_array(s), f = [].concat(f), r = [].concat(r), i = (s = [].concat(s)).length;
 
	while (j = 0, i--) {
		while (s[i] = s[i].split(f[j]).join(ra ? r[j] || '' : r[0]), ++j in f){};
	};
	 
	return sa ? s : s[0];
}

//by: HACKERSOFT
function SelectUnselectLevels(Code) {
	if (document.getElementById("CID" + Code).checked == true) {
		document.getElementById('vis').value += Code + '.';
	} else {
		document.getElementById('vis').value = str_replace('.' + Code + '.', '.', document.getElementById('vis').value);
	}
}

/*
	Menu Builder for JSCookMenu and JSCookTree
	Infused and Modified for PHP-Fusion by EDAN BOY PEDRAGOSA alias HACKERSOFT
	v1.0. (c) Copyright 2002 by Heng Yuan

	Permission is hereby granted, free of charge, to any person obtaining a
	copy of this software and associated documentation files (the \"Software\"),
	to deal in the Software without restriction, including without limitation
	the rights to use, copy, modify, merge, publish, distribute, sublicense,
	and/or sell copies of the Software, and to permit persons to whom the
	Software is furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included
	in all copies or substantial portions of the Software.

	THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	ITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
	FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
	DEALINGS IN THE SOFTWARE.
*/

